/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.request;

import java.util.ArrayList;
import java.util.List;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.faces.context.FacesContext;

import kieker.analysis.model.analysisMetaModel.MIDependency;
import kieker.analysis.model.analysisMetaModel.MIProject;
import kieker.webgui.beans.session.SelectedProjectBean;

/**
 * This bean contains the currently choosen dependencies.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@RequestScoped
public class SelectedDependenciesBean {

	private List<MIDependency> dependencies;
	private final MIProject project;

	public SelectedDependenciesBean() {
		this.dependencies = new ArrayList<MIDependency>();

		final FacesContext context = FacesContext.getCurrentInstance();

		final SelectedProjectBean selProjBean = context.getApplication().evaluateExpressionGet(context, "#{selectedProjectBean}",
				SelectedProjectBean.class);
		if (selProjBean != null) {
			this.project = selProjBean.getSelectedProject();
		} else {
			this.project = null;
		}
	}

	//
	// /**
	// * A dual model containing all available dependencies and the currently choosen one.
	// */
	// private DualListModel<MIDependency> dependencies;
	// /**
	// * The currently selected project.
	// */
	// private final MIProject project;
	//
	// /**
	// * Creates a new instance of this class.
	// */
	// public SelectedDependenciesBean() {
	// final List<MIDependency> source = new ArrayList<MIDependency>();
	// final List<MIDependency> target = new ArrayList<MIDependency>();
	//
	// this.dependencies = new DualListModel<MIDependency>(source, target);
	//
	// final FacesContext context = FacesContext.getCurrentInstance();
	//
	// final SelectedProjectBean selProjBean = context.getApplication().evaluateExpressionGet(context, "#{selectedProjectBean}",
	// SelectedProjectBean.class);
	// if (selProjBean != null) {
	// this.project = selProjBean.getSelectedProject();
	// } else {
	// this.project = null;
	// }
	//
	// /* Get all available libs. */
	//
	// final AvailableDependenciesBean availDepBean = context.getApplication().evaluateExpressionGet(context, "#{availableDependenciesBean}",
	// AvailableDependenciesBean.class);
	// this.dependencies.getSource().clear();
	// if (availDepBean != null) {
	// this.dependencies.getSource().addAll(availDepBean.getDependencies());
	// }
	// this.dependencies.getTarget().clear();
	//
	// /* Now move the already selected to the right side. */
	// if (this.project != null) {
	// final List<MIDependency> projectLibs = this.project.getDependencies();
	// for (final MIDependency lib : projectLibs) {
	// this.dependencies.getSource().remove(lib);
	// this.dependencies.getTarget().add(lib);
	// }
	// }
	// }
	//
	// /**
	// * Delivers the stored dependencies within this bean.
	// *
	// * @return The dependencies dual model.
	// */
	// public final DualListModel<MIDependency> getDependencies() {
	// return this.dependencies;
	// }
	//
	// /**
	// * Sets the dependencies to be stored within this bean to a new value.
	// *
	// * @param dependencies
	// * The new dependencies dual model.
	// */
	// public final void setDependencies(final DualListModel<MIDependency> dependencies) {
	// this.dependencies = dependencies;
	// /* Remember the selected libs. */
	// if (this.project != null) {
	// this.project.getDependencies().clear();
	// this.project.getDependencies().addAll(dependencies.getTarget());
	// }
	// }

	public List<MIDependency> getDependencies() {
		return this.dependencies;
	}

	public void setDependencies(final List<MIDependency> dependencies) {
		this.dependencies = dependencies;
	}

	public void submit() {
		// TODO Error while executing this method
		if (this.project != null) {
			this.project.getDependencies().clear();
			this.project.getDependencies().addAll(this.dependencies);
		}
	}

}
