/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.common;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;

import kieker.analysis.plugin.annotation.Plugin;

/**
 * @author Nils Christian Ehmke
 * @version 1.0
 */
public final class PluginFinder {

	/**
	 * Creates a new instance of this class.
	 */
	private PluginFinder() {}

	/**
	 * This method delivers all classes which are available in the given jar and
	 * has the Plugin-Annotation from the Kieker framework.
	 * 
	 * @param url
	 *            The url for the jar.
	 * @return A list containing all available plugin-classes or null, if an
	 *         exception occured.
	 */
	public static List<Class<?>> getAllPluginsWithinJar(final URL url) {
		try {
			/*
			 * Open the jar file and run through all entries within this file.
			 */
			final JarFile jarFile = new JarFile(new File(url.getPath()));
			final List<Class<?>> result = new ArrayList<Class<?>>();
			final Enumeration<JarEntry> jarEntries = jarFile.entries();
			while (jarEntries.hasMoreElements()) {
				final JarEntry jarEntry = jarEntries.nextElement();
				try {
					String name = jarEntry.toString();
					name = name.replace('/', '.');
					name = name.replace(".class", "");
					/*
					 * Try to find a class with the same name.
					 */
					final Class<?> c = PluginClassLoader.getInstance().loadClass(name);
					/*
					 * If it is a class and has the annotation - put it into our
					 * list.
					 */
					if (c.isAnnotationPresent(Plugin.class)) {
						result.add(c);
					}
				} catch (final Throwable ex) {
					/* Ignore error. */
				}
			}
			jarFile.close();
			return result;
		} catch (final IOException ex) {
			ex.printStackTrace();
		}
		return null;
	}
}
